@@ -34,9 +34,11 @@ import tempfile
 import functools
 import re
 import contextlib
-import io
 import importlib
 import itertools
+import datetime
+from numbers import Number
+from typing import Union
 
 with contextlib.suppress(ImportError):
     import win32security
@@ -50,7 +52,6 @@ with contextlib.suppress(ImportError):
 from . import matchers
 from . import masks
 from . import classes
-from .py37compat import best_realpath, lru_cache
 
 
 __all__ = ['Path', 'TempDir']
@@ -66,6 +67,11 @@ U_NL_END = re.compile(U_NEWLINE.pattern + '$')
 _default_linesep = object()
 
 
+def _make_timestamp_ns(value: Union[Number, datetime.datetime]) -> Number:
+    timestamp_s = value if isinstance(value, Number) else value.timestamp()
+    return int(timestamp_s * 10**9)
+
+
 class TreeWalkWarning(Warning):
     pass
 
@@ -143,7 +149,7 @@ class Path(str):
             self._validate()
 
     @classmethod
-    @lru_cache
+    @functools.lru_cache
     def using_module(cls, module):
         subclass_name = cls.__name__ + '_' + module.__name__
         bases = (cls,)
@@ -161,11 +167,11 @@ class Path(str):
     # --- Special Python methods.
 
     def __repr__(self):
-        return '%s(%s)' % (type(self).__name__, super(Path, self).__repr__())
+        return '{}({})'.format(type(self).__name__, super().__repr__())
 
     # Adding a Path and a string yields a Path.
     def __add__(self, more):
-        return self._next_class(super(Path, self).__add__(more))
+        return self._next_class(super().__add__(more))
 
     def __radd__(self, other):
         return self._next_class(other.__add__(self))
@@ -231,8 +237,7 @@ class Path(str):
 
     def realpath(self):
         """.. seealso:: :func:`os.path.realpath`"""
-        realpath = best_realpath(self.module)
-        return self._next_class(realpath(self))
+        return self._next_class(self.module.realpath(self))
 
     def expanduser(self):
         """.. seealso:: :func:`os.path.expanduser`"""
@@ -290,7 +295,7 @@ class Path(str):
         ValueError: Invalid suffix 'zip'
         """
         if not suffix.startswith('.'):
-            raise ValueError("Invalid suffix {suffix!r}".format(**locals()))
+            raise ValueError(f"Invalid suffix {suffix!r}")
 
         return self.stripext() + suffix
 
@@ -543,8 +548,7 @@ class Path(str):
                 continue
 
             if do_traverse:
-                for item in child.walk(errors=errors, match=match):
-                    yield item
+                yield from child.walk(errors=errors, match=match)
 
     def walkdirs(self, *args, **kwargs):
         """Iterator over subdirs, recursively."""
@@ -617,7 +621,7 @@ class Path(str):
         Keyword arguments work as in :func:`io.open`.  If the file cannot be
         opened, an :class:`OSError` is raised.
         """
-        return io.open(self, *args, **kwargs)
+        return open(self, *args, **kwargs)
 
     def bytes(self):
         """Open this file, read all bytes, return them as a string."""
@@ -633,14 +637,13 @@ class Path(str):
         :example:
 
             >>> hash = hashlib.md5()
-            >>> for chunk in Path("CHANGES.rst").chunks(8192, mode='rb'):
+            >>> for chunk in Path("NEWS.rst").chunks(8192, mode='rb'):
             ...     hash.update(chunk)
 
          This will read the file by chunks of 8192 bytes.
         """
         with self.open(*args, **kwargs) as f:
-            for chunk in iter(lambda: f.read(size) or None, None):
-                yield chunk
+            yield from iter(lambda: f.read(size) or None, None)
 
     def write_bytes(self, bytes, append=False):
         """Open this file and write the given bytes to it.
@@ -906,9 +909,13 @@ class Path(str):
         """.. seealso:: :attr:`atime`, :func:`os.path.getatime`"""
         return self.module.getatime(self)
 
+    def set_atime(self, value):
+        mtime_ns = self.stat().st_atime_ns
+        self.utime(ns=(_make_timestamp_ns(value), mtime_ns))
+
     atime = property(
         getatime,
-        None,
+        set_atime,
         None,
         """
         Last access time of the file.
@@ -916,6 +923,14 @@ class Path(str):
         >>> Path('.').atime > 0
         True
 
+        Allows setting:
+
+        >>> some_file = Path(getfixture('tmp_path')).joinpath('file.txt').touch()
+        >>> MST = datetime.timezone(datetime.timedelta(hours=-7))
+        >>> some_file.atime = datetime.datetime(1976, 5, 7, 10, tzinfo=MST)
+        >>> some_file.atime
+        200336400.0
+
         .. seealso:: :meth:`getatime`, :func:`os.path.getatime`
         """,
     )
@@ -924,13 +939,25 @@ class Path(str):
         """.. seealso:: :attr:`mtime`, :func:`os.path.getmtime`"""
         return self.module.getmtime(self)
 
+    def set_mtime(self, value):
+        atime_ns = self.stat().st_atime_ns
+        self.utime(ns=(atime_ns, _make_timestamp_ns(value)))
+
     mtime = property(
         getmtime,
-        None,
+        set_mtime,
         None,
         """
         Last modified time of the file.
 
+        Allows setting:
+
+        >>> some_file = Path(getfixture('tmp_path')).joinpath('file.txt').touch()
+        >>> MST = datetime.timezone(datetime.timedelta(hours=-7))
+        >>> some_file.mtime = datetime.datetime(1976, 5, 7, 10, tzinfo=MST)
+        >>> some_file.mtime
+        200336400.0
+
         .. seealso:: :meth:`getmtime`, :func:`os.path.getmtime`
         """,
     )
@@ -963,6 +990,21 @@ class Path(str):
         """,
     )
 
+    @property
+    def permissions(self) -> masks.Permissions:
+        """
+        Permissions.
+
+        >>> perms = Path('.').permissions
+        >>> isinstance(perms, int)
+        True
+        >>> set(perms.symbolic) <= set('rwx-')
+        True
+        >>> perms.symbolic
+        'r...'
+        """
+        return masks.Permissions(self.stat().st_mode)
+
     def access(self, *args, **kwargs):
         """
         Return does the real user have access to this path.
@@ -1073,6 +1115,12 @@ class Path(str):
         Set the mode. May be the new mode (os.chmod behavior) or a `symbolic
         mode <http://en.wikipedia.org/wiki/Chmod#Symbolic_modes>`_.
 
+        >>> a_file = Path(getfixture('tmp_path')).joinpath('afile.txt').touch()
+        >>> a_file.chmod(0o700)
+        Path(...
+        >>> a_file.chmod('u+x')
+        Path(...
+
         .. seealso:: :func:`os.chmod`
         """
         if isinstance(mode, str):
@@ -1366,7 +1414,7 @@ class Path(str):
         backup_fn = self + (backup_extension or os.extsep + 'bak')
         backup_fn.remove_p()
         self.rename(backup_fn)
-        readable = io.open(
+        readable = open(
             backup_fn,
             mode,
             buffering=buffering,
@@ -1388,7 +1436,7 @@ class Path(str):
             os_mode = os.O_CREAT | os.O_WRONLY | os.O_TRUNC
             os_mode |= getattr(os, 'O_BINARY', 0)
             fd = os.open(self, os_mode, perm)
-            writable = io.open(
+            writable = open(
                 fd,
                 "w" + mode.replace('r', ''),
                 buffering=buffering,
@@ -1520,7 +1568,7 @@ class SpecialResolver:
         Return the callable function from appdirs, but with the
         result wrapped in self.path_class
         """
-        prop_name = '{scope}_{class_}_dir'.format(**locals())
+        prop_name = f'{scope}_{class_}_dir'
         value = getattr(self.wrapper, prop_name)
         MultiPath = Multi.for_class(self.path_class)
         return MultiPath.detect(value)
@@ -1581,7 +1629,7 @@ class TempDir(Path):
 
     def __new__(cls, *args, **kwargs):
         dirname = tempfile.mkdtemp(*args, **kwargs)
-        return super(TempDir, cls).__new__(cls, dirname)
+        return super().__new__(cls, dirname)
 
     def __init__(self, *args, **kwargs):
         pass
